@@ -7,6 +7,8 @@ import traceback
 import webbrowser
 
 import dclab
+from dclab.lme4.rlibs import rpy2, MockRPackage
+from dclab.lme4 import rsetup
 import h5py
 import numpy
 import scipy
@@ -94,11 +96,16 @@ class ShapeOut2(QtWidgets.QMainWindow):
         self.actionChangeDatasetOrder.triggered.connect(
             self.on_action_change_dataset_order)
         self.actionPreferences.triggered.connect(self.on_action_preferences)
+        # Bulk action menu
+        self.actionComputeEmodulus.triggered.connect(
+            self.on_action_compute_emodulus)
         # Compute menu
         self.actionComputeStatistics.triggered.connect(
             self.on_action_compute_statistics)
-        self.actionComputeEmodulus.triggered.connect(
-            self.on_action_compute_emodulus)
+        self.actionComputeSignificance.triggered.connect(
+            self.on_action_compute_significance)
+        self.actionComputeSignificance.setVisible(
+            not isinstance(rpy2, MockRPackage))  # only show if rpy2 is there
         # Export menu
         self.actionExportData.triggered.connect(self.on_action_export_data)
         self.actionExportFilter.triggered.connect(self.on_action_export_filter)
@@ -163,7 +170,8 @@ class ShapeOut2(QtWidgets.QMainWindow):
         # if "--version" was specified, print the version and exit
         if "--version" in sys.argv:
             print(__version__)
-            QtWidgets.QApplication.processEvents()
+            QtWidgets.QApplication.processEvents(QtCore.QEventLoop.AllEvents,
+                                                 300)
             sys.exit(0)
         # check pyqtgraph version
         self._check_pg_version()
@@ -180,17 +188,17 @@ class ShapeOut2(QtWidgets.QMainWindow):
     def _check_pg_version(self):
         """Tells the user if the pyqtgraph version is not correct"""
         if (int(self.settings.value("advanced/check pyqtgraph version", 1))
-                and pg.__version__ != "0.11.0.dev0+g1c63ae5"):
+                and pg.__version__ != "0.11.1.dev0-c1900-shapeout"):
             msg = QtWidgets.QMessageBox()
             msg.setIcon(QtWidgets.QMessageBox.Warning)
             msg.setText("You are using an unexpected version of pyqtgraph. "
-                        + "Plot export may not work correctly!")
+                        + "Plotting may not work correctly!")
             msg.setWindowTitle("pyqtgraph version mismatch")
             msg.setDetailedText(
                 "If you have installed Shape-Out using pip, please "
-                + "install our pyqtgraph fork using: \n\n"
-                + "pip install "
-                + "git+git://github.com/ZELLMECHANIK-DRESDEN/pyqtgraph.git"
+                + "install our pyqtgraph fork via: \n\n"
+                + "pip install git+git://github.com/ZELLMECHANIK-DRESDEN/"
+                + "pyqtgraph.git@master-c1900"
             )
             msg.exec_()
 
@@ -535,15 +543,27 @@ class ShapeOut2(QtWidgets.QMainWindow):
         msg.setText(text)
         msg.exec_()
 
-    def on_action_compute_statistics(self):
-        dlg = compute.ComputeStatistics(self, pipeline=self.pipeline)
-        dlg.exec()
-
     def on_action_compute_emodulus(self):
         dlg = bulk.BulkActionEmodulus(self, pipeline=self.pipeline)
         dlg.pipeline_changed.connect(self.adopt_pipeline)
         dlg.exec()
 
+    def on_action_compute_significance(self):
+        # check that R is available
+        if rsetup.has_r():
+            dlg = compute.ComputeSignificance(self, pipeline=self.pipeline)
+            dlg.exec()
+        else:
+            QtWidgets.QMessageBox.critical(
+                self, "R not found!",
+                "The R executable was not found by rpy2. Please add it "
+                + "to the PATH variable or define it manually in the "
+                + "Shape-Out preferences.")
+
+    def on_action_compute_statistics(self):
+        dlg = compute.ComputeStatistics(self, pipeline=self.pipeline)
+        dlg.exec()
+
     @QtCore.pyqtSlot()
     def on_action_clear(self, assume_yes=False):
         if assume_yes:
@@ -651,6 +671,9 @@ class ShapeOut2(QtWidgets.QMainWindow):
                 pg,
                 scipy,
                 ]
+        if not isinstance(rpy2, MockRPackage):
+            libs.append(rpy2)
+
         sw_text = "Shape-Out {}\n\n".format(__version__)
         sw_text += "Python {}\n\n".format(sys.version)
         sw_text += "Modules:\n"
