@@ -44,13 +44,15 @@ class PipelinePlot(QtWidgets.QWidget):
     instances = {}
 
     def __init__(self, parent, pipeline, plot_id, *args, **kwargs):
-        QtWidgets.QWidget.__init__(self, parent=parent, *args, **kwargs)
+        super(PipelinePlot, self).__init__(parent=parent, *args, **kwargs)
         path_ui = pkg_resources.resource_filename(
             "shapeout2.gui", "pipeline_plot.ui")
         uic.loadUi(path_ui, self)
         # used to avoid unnecessary plotting
         self._plot_data_hash = "unset"
 
+        #: Contains the PipelinePlotItmes
+        self.plot_items = []
         self.pipeline = pipeline
         self.identifier = plot_id
         self.update_content()
@@ -118,9 +120,12 @@ class PipelinePlot(QtWidgets.QWidget):
         self.plot_layout.addLabel(labely, angle=-90)
         linner = self.plot_layout.addLayout()
 
+        self.plot_items.clear()
+
         # limits in case of scatter plot and feature hue
         if lay["division"] == "merge":
             pp = PipelinePlotItem(parent=linner)
+            self.plot_items.append(pp)
             linner.addItem(item=pp,
                            row=None,
                            col=None,
@@ -131,6 +136,7 @@ class PipelinePlot(QtWidgets.QWidget):
             colcount = 0
             for ds, sl in zip(dslist, slot_states):
                 pp = PipelinePlotItem(parent=linner)
+                self.plot_items.append(pp)
                 linner.addItem(item=pp,
                                row=None,
                                col=None,
@@ -147,6 +153,7 @@ class PipelinePlot(QtWidgets.QWidget):
             plot_state_scatter["contour"]["enabled"] = False
             for ds, sl in zip(dslist, slot_states):
                 pp = PipelinePlotItem(parent=linner)
+                self.plot_items.append(pp)
                 linner.addItem(item=pp,
                                row=None,
                                col=None,
@@ -160,6 +167,7 @@ class PipelinePlot(QtWidgets.QWidget):
             plot_state_contour = copy.deepcopy(plot_state)
             plot_state_contour["scatter"]["enabled"] = False
             pp = PipelinePlotItem(parent=linner)
+            self.plot_items.append(pp)
             linner.addItem(item=pp,
                            row=None,
                            col=None,
@@ -245,8 +253,7 @@ class PipelinePlotItem(SimplePlotItem):
         win.nextRow()
         win.addLabel(labelx, col=1)
         # Update the UI (do it twice, otherwise the tick labels overlap)
-        QtWidgets.QApplication.processEvents()
-        QtWidgets.QApplication.processEvents()
+        QtWidgets.QApplication.processEvents(QtCore.QEventLoop.AllEvents, 300)
         win.hide()
         # perform actual export
         suffix = file[-3:]
@@ -415,7 +422,7 @@ def add_isoelastics(plot_item, axis_x, axis_y, channel_width, pixel_size):
     # in Shape-Out 1.
     try:
         iso = isodef.get(
-            method="numerical",
+            lut_identifier="LE-2D-FEM-19",
             channel_width=channel_width,
             flow_rate=None,
             viscosity=None,
